California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 067- REFERENDUM TO OVERTURN BAN ON SINGLE-USE PLASTIC BAGS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372900 | YES ON 67 - PROTECT THE PLASTIC BAG BAN, SPONSORED BY ENVIRONMENTAL AND OCEAN PROTECTION ORGANIZATIONS, BUSINESSES INCLUDING GROCERS AND REUSABLE BAG MAKERS, AND OTHER NONPROFIT ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372902 | AMERICAN PROGRESSIVE BAG ALLIANCE, A PROJECT OF THE SOCIETY OF THE PLASTICS INDUSTRY (NON-PROFIT 501 (C) (6)), YES ON 65 AND NO ON 67 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1329332 | SAVE THE BAG BAN, YES ON 67, SPONSORED BY ENVIRONMENT CALIFORNIA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1374885 | YES ON 67 - CALIFORNIANS AGAINST WASTE - PROTECT THE PLASTIC BAN (NON-PROFIT 501 (C) (4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346973 | CALIFORNIA GROCERS ASSOCIATION ISSUES COMMITTEE (NON-PROFIT 501(C) 6): YES ON PROPOSITION 67 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1381938 | SAVE THE BAY ACTION FUND PAC - YES ON PROP 67 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1389817 | SAVE THE BAY ACTION FUND COMMITTEE TO SUPPORT PROPOSITION 67 | SUPPORT